@@ -1,6 +1,6 @@
 #' Daily IMGW meteorological data
 #'
-#' Downloading daily (meteorological) data from the SYNOP / CLIMATE / PRECIP stations available in the dane.imgw.pl collection
+#' Downloading daily (meteorological) data from the SYNOP / CLIMATE / PRECIP stations available in the danepubliczne.imgw.pl collection
 #'
 #' @param rank rank of the stations: "synop" (default), "climate", or "precip"
 #' @param year vector of years (e.g., 1966:2000)
@@ -24,7 +24,9 @@ meteo_imgw_daily <- function(rank = "synop", year, status = FALSE, coords = FALS
 
   #options(RCurlOptions = list(ssl.verifypeer = FALSE)) # required on windows for RCurl
   
-  base_url <- "https://dane.imgw.pl/data/dane_pomiarowo_obserwacyjne/"
+  check_locale()
+  
+  base_url <- "https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/"
   
   interval <- "daily" # to mozemy ustawic na sztywno
   interval_pl <- "dobowe"
